==> mx-datetime_19.9.3.tar.xz: mx-datetime-19.9.3/translations/mx-datetime_pl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl">
<context>
    <name>MXDateTime</name>
    <message>
        <location filename="../datetime.ui" line="20"/>
        <location filename="../datetime.cpp" line="596"/>
        <source>MX Date &amp; Time</source>
        <translation>MX Data i godzina</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="26"/>
        <source>Close</source>
        <translation>Zamknij</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="40"/>
        <source>Help</source>
        <translation>Pomoc</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="73"/>
        <source>Apply</source>
        <translation>Zastosuj</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="100"/>
        <source>About...</source>
        <translation>O...</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="124"/>
        <source>Date &amp;&amp; Time</source>
        <translation>Data i godzina</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="192"/>
        <source>H:mm:ss</source>
        <translation>H:mm:ss</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="278"/>
        <location filename="../datetime.cpp" line="296"/>
        <location filename="../datetime.cpp" line="303"/>
        <source>Hardware Clock</source>
        <translation>Zegar sprzętowy</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="284"/>
        <source>Hardware Clock tools</source>
        <translation>Narzędzia zegara sprzętowego</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="290"/>
        <source>Obtain information from the Hardware Clock and present it in the box below.</source>
        <translation>Pobierz informacje z zegara sprzętowego i pokaż je w poniższym polu.</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="293"/>
        <source>Read the Hardware Clock</source>
        <translation>Odczytaj czas z zegara sprzętowego</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="303"/>
        <source>Apply systematic drift corrections to the Hardware Clock.</source>
        <translation>Zastosuj systematyczne korekty przesunięcia czasu do zegara sprzętowego.</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="306"/>
        <source>Drift Adjust</source>
        <translation>Regulacja przesunięcia czasowego</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="329"/>
        <source>Time transfer</source>
        <translation>Transfer czasu</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="335"/>
        <source>Immediately set the System Clock to match the current time registered by the Hardware Clock.</source>
        <translation>Natychmiast ustaw zegar systemowy zgodnie z bieżącym czasem zarejestrowanym przez zegar sprzętowy.</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="338"/>
        <source>Hardware Clock to System Clock</source>
        <translation>Zegar sprzętowy na zegar systemowy</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="348"/>
        <source>Immediately set the Hardware Clock to match the current time registered by the System Clock.</source>
        <translation>Natychmiast ustaw zegar sprzętowy zgodnie z bieżącym czasem zarejestrowanym przez zegar systemowy.</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="351"/>
        <source>System Clock to Hardware Clock</source>
        <translation>Zegar systemowy na zegar sprzętowy</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="361"/>
        <source>Update the drift factor for the Hardware Clock when it is being set.</source>
        <translation>Zaktualizuj przesunięcie czasowe dla zegara sprzętowego podczas jego ustawiania.</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="364"/>
        <source>Update the drift</source>
        <translation>Zaktualizuj przesunięcie czasowe</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="374"/>
        <source>Time zone for the Hardware Clock</source>
        <translation>Strefa czasowa dla zegara sprzętowego</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="380"/>
        <source>Local time</source>
        <translation>Czas lokalny</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="383"/>
        <source>Local</source>
        <translation>Lokalna</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="390"/>
        <source>Universally Coordinated Time (or Greenwich Meridian Time)</source>
        <translation>Uniwersalny czas koordynowany UTC (inaczej Czas Południkowy Greenwich)</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="393"/>
        <source>UTC</source>
        <translation>UTC</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="433"/>
        <source>Network Time</source>
        <translation>Czas sieciowy</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="439"/>
        <source>Move the selected item down</source>
        <translation>Przenieś wybrany element w dół</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="450"/>
        <source>Move the selected item up</source>
        <translation>Przenieś wybrany element w górę</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="461"/>
        <source>Remove the current item from the list</source>
        <translation>Usuń bieżący element z listy</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="472"/>
        <source>Add an item to the list</source>
        <translation>Dodaj element do listy</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="498"/>
        <source>Automatically update the System Clock with NTP servers:</source>
        <translation>Automatycznie aktualizuj zegar systemowy z serwerami NTP:</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="505"/>
        <source>Immediately update the system clock with NTP servers.</source>
        <translation>Natychmiast zaktualizuj zegar systemowy z serwerami NTP.</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="508"/>
        <source>Update Now</source>
        <translation>Aktualizuj teraz</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="520"/>
        <source>List of NTP servers to use.</source>
        <translation>Lista serwerów NTP do użycia.</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="536"/>
        <source>Type</source>
        <translation>Typ</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="541"/>
        <source>Address</source>
        <translation>Adres</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="546"/>
        <source>Options</source>
        <translation>Opcje</translation>
    </message>
    <message>
        <location filename="../datetime.cpp" line="270"/>
        <source>Reading...</source>
        <translation>Odczytywanie...</translation>
    </message>
    <message>
        <location filename="../datetime.cpp" line="284"/>
        <source>Adjusting...</source>
        <translation>Regulowanie...</translation>
    </message>
    <message>
        <location filename="../datetime.cpp" line="296"/>
        <location filename="../datetime.cpp" line="303"/>
        <source>System Clock</source>
        <translation>Zegar systemowy</translation>
    </message>
    <message>
        <location filename="../datetime.cpp" line="309"/>
        <source>The %1 time was transferred to the %2.</source>
        <translation>Czas %1 został przeniesiony do %2.</translation>
    </message>
    <message>
        <location filename="../datetime.cpp" line="312"/>
        <source>The %1 time could not be transferred to the %2.</source>
        <translation>Nie można przenieść czasu %1 do %2.</translation>
    </message>
    <message>
        <location filename="../datetime.cpp" line="350"/>
        <source>Updating...</source>
        <translation>Aktualizowanie...</translation>
    </message>
    <message>
        <location filename="../datetime.cpp" line="360"/>
        <source>The system clock was updated successfully.</source>
        <translation>Zegar systemowy został pomyślnie zaktualizowany.</translation>
    </message>
    <message>
        <location filename="../datetime.cpp" line="362"/>
        <source>The system clock could not be updated.</source>
        <translation>Nie można zaktualizować zegara systemowego.</translation>
    </message>
    <message>
        <location filename="../datetime.cpp" line="364"/>
        <source>None of the NTP servers on the list are currently enabled.</source>
        <translation>Żaden z serwerów NTP na liście nie jest obecnie dostępny.</translation>
    </message>
    <message>
        <location filename="../datetime.cpp" line="595"/>
        <source>About MX Date &amp; Time</source>
        <translation>O programie MX Data i godzina</translation>
    </message>
    <message>
        <location filename="../datetime.cpp" line="596"/>
        <source>Version: </source>
        <translation>Wersja:</translation>
    </message>
    <message>
        <location filename="../datetime.cpp" line="597"/>
        <source>GUI program for setting the time and date in MX Linux</source>
        <translation>Program GUI do ustawiania czasu i daty w MX Linux</translation>
    </message>
    <message>
        <location filename="../datetime.cpp" line="599"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Prawa autorskie © MX Linux</translation>
    </message>
    <message>
        <location filename="../datetime.cpp" line="600"/>
        <location filename="../datetime.cpp" line="614"/>
        <source>License</source>
        <translation>Licencja</translation>
    </message>
    <message>
        <location filename="../datetime.cpp" line="601"/>
        <source>Changelog</source>
        <translation>Dziennik zmian</translation>
    </message>
    <message>
        <location filename="../datetime.cpp" line="602"/>
        <source>Cancel</source>
        <translation>Anuluj</translation>
    </message>
    <message>
        <location filename="../datetime.cpp" line="628"/>
        <source>&amp;Close</source>
        <translation>&amp;Zamknij</translation>
    </message>
    <message>
        <location filename="../datetime.cpp" line="646"/>
        <source>MX Date &amp; Time Help</source>
        <translation>Pomoc MX Data i godzina</translation>
    </message>
</context>
</TS>

==> mx-datetime_21.11.tar.xz: mx-datetime-21.11/translations/mx-datetime_pl.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="pl" version="2.1">
<context>
    <name>MXDateTime</name>
    <message>
        <location filename="datetime.ui" line="20"/>
        <location filename="datetime.cpp" line="596"/>
        <source>MX Date &amp; Time</source>
        <translation>MX Data i godzina</translation>
    </message>
    <message>
        <location filename="datetime.ui" line="26"/>
        <source>Close</source>
        <translation>Zamknij</translation>
    </message>
    <message>
        <location filename="datetime.ui" line="40"/>
        <source>Help</source>
        <translation>Pomoc</translation>
    </message>
    <message>
        <location filename="datetime.ui" line="73"/>
        <source>Apply</source>
        <translation>Zastosuj</translation>
    </message>
    <message>
        <location filename="datetime.ui" line="100"/>
        <source>About...</source>
        <translation>O...</translation>
    </message>
    <message>
        <location filename="datetime.ui" line="124"/>
        <source>Date &amp;&amp; Time</source>
        <translation>Data i godzina</translation>
    </message>
    <message>
        <location filename="datetime.ui" line="192"/>
        <source>H:mm:ss</source>
        <translation>H:mm:ss</translation>
    </message>
    <message>
        <location filename="datetime.ui" line="278"/>
        <location filename="datetime.cpp" line="296"/>
        <location filename="datetime.cpp" line="303"/>
        <source>Hardware Clock</source>
        <translation>Zegar sprzętowy</translation>
    </message>
    <message>
        <location filename="datetime.ui" line="284"/>
        <source>Hardware Clock tools</source>
        <translation>Narzędzia zegara sprzętowego</translation>
    </message>
    <message>
        <location filename="datetime.ui" line="290"/>
        <source>Obtain information from the Hardware Clock and present it in the box below.</source>
        <translation>Pobierz informacje z zegara sprzętowego i pokaż je w poniższym polu.</translation>
    </message>
    <message>
        <location filename="datetime.ui" line="293"/>
        <source>Read the Hardware Clock</source>
        <translation>Odczytaj czas z zegara sprzętowego</translation>
    </message>
    <message>
        <location filename="datetime.ui" line="300"/>
        <source>Apply systematic drift corrections to the Hardware Clock.</source>
        <translation>Zastosuj systematyczne korekty przesunięcia czasu do zegara sprzętowego.</translation>
    </message>
    <message>
        <location filename="datetime.ui" line="303"/>
        <source>Drift Adjust</source>
        <translation>Regulacja przesunięcia czasowego</translation>
    </message>
    <message>
        <location filename="datetime.ui" line="323"/>
        <source>Time transfer</source>
        <translation>Transfer czasu</translation>
    </message>
    <message>
        <location filename="datetime.ui" line="329"/>
        <source>Immediately set the System Clock to match the current time registered by the Hardware Clock.</source>
        <translation>Natychmiast ustaw zegar systemowy zgodnie z bieżącym czasem zarejestrowanym przez zegar sprzętowy.</translation>
    </message>
    <message>
        <location filename="datetime.ui" line="332"/>
        <source>Hardware Clock to System Clock</source>
        <translation>Zegar sprzętowy na zegar systemowy</translation>
    </message>
    <message>
        <location filename="datetime.ui" line="339"/>
        <source>Immediately set the Hardware Clock to match the current time registered by the System Clock.</source>
        <translation>Natychmiast ustaw zegar sprzętowy zgodnie z bieżącym czasem zarejestrowanym przez zegar systemowy.</translation>
    </message>
    <message>
        <location filename="datetime.ui" line="342"/>
        <source>System Clock to Hardware Clock</source>
        <translation>Zegar systemowy na zegar sprzętowy</translation>
    </message>
    <message>
        <location filename="datetime.ui" line="349"/>
        <source>Update the drift factor for the Hardware Clock when it is being set.</source>
        <translation>Zaktualizuj przesunięcie czasowe dla zegara sprzętowego podczas jego ustawiania.</translation>
    </message>
    <message>
        <location filename="datetime.ui" line="352"/>
        <source>Update the drift</source>
        <translation>Zaktualizuj przesunięcie czasowe</translation>
    </message>
    <message>
        <location filename="datetime.ui" line="362"/>
        <source>Time zone for the Hardware Clock</source>
        <translation>Strefa czasowa dla zegara sprzętowego</translation>
    </message>
    <message>
        <location filename="datetime.ui" line="368"/>
        <source>Local time</source>
        <translation>Czas lokalny</translation>
    </message>
    <message>
        <location filename="datetime.ui" line="371"/>
        <source>Local</source>
        <translation>Lokalna</translation>
    </message>
    <message>
        <location filename="datetime.ui" line="378"/>
        <source>Universally Coordinated Time (or Greenwich Meridian Time)</source>
        <translation>Uniwersalny czas koordynowany UTC (inaczej Czas Południkowy Greenwich)</translation>
    </message>
    <message>
        <location filename="datetime.ui" line="381"/>
        <source>UTC</source>
        <translation>UTC</translation>
    </message>
    <message>
        <location filename="datetime.ui" line="421"/>
        <source>Network Time</source>
        <translation>Czas sieciowy</translation>
    </message>
    <message>
        <location filename="datetime.ui" line="427"/>
        <source>Move the selected item down</source>
        <translation>Przenieś wybrany element w dół</translation>
    </message>
    <message>
        <location filename="datetime.ui" line="438"/>
        <source>Move the selected item up</source>
        <translation>Przenieś wybrany element w górę</translation>
    </message>
    <message>
        <location filename="datetime.ui" line="449"/>
        <source>Remove the current item from the list</source>
        <translation>Usuń bieżący element z listy</translation>
    </message>
    <message>
        <location filename="datetime.ui" line="460"/>
        <source>Add an item to the list</source>
        <translation>Dodaj element do listy</translation>
    </message>
    <message>
        <location filename="datetime.ui" line="486"/>
        <source>Automatically update the System Clock with NTP servers:</source>
        <translation>Automatycznie aktualizuj zegar systemowy z serwerami NTP:</translation>
    </message>
    <message>
        <location filename="datetime.ui" line="493"/>
        <source>Immediately update the system clock with NTP servers.</source>
        <translation>Natychmiast zaktualizuj zegar systemowy z serwerami NTP.</translation>
    </message>
    <message>
        <location filename="datetime.ui" line="496"/>
        <source>Update Now</source>
        <translation>Aktualizuj teraz</translation>
    </message>
    <message>
        <location filename="datetime.ui" line="505"/>
        <source>List of NTP servers to use.</source>
        <translation>Lista serwerów NTP do użycia.</translation>
    </message>
    <message>
        <location filename="datetime.ui" line="521"/>
        <source>Type</source>
        <translation>Typ</translation>
    </message>
    <message>
        <location filename="datetime.ui" line="526"/>
        <source>Address</source>
        <translation>Adres</translation>
    </message>
    <message>
        <location filename="datetime.ui" line="531"/>
        <source>Options</source>
        <translation>Opcje</translation>
    </message>
    <message>
        <location filename="datetime.cpp" line="270"/>
        <source>Reading...</source>
        <translation>Odczytywanie...</translation>
    </message>
    <message>
        <location filename="datetime.cpp" line="284"/>
        <source>Adjusting...</source>
        <translation>Regulowanie...</translation>
    </message>
    <message>
        <location filename="datetime.cpp" line="296"/>
        <location filename="datetime.cpp" line="303"/>
        <source>System Clock</source>
        <translation>Zegar systemowy</translation>
    </message>
    <message>
        <location filename="datetime.cpp" line="309"/>
        <source>The %1 time was transferred to the %2.</source>
        <translation>Czas %1 został przeniesiony do %2.</translation>
    </message>
    <message>
        <location filename="datetime.cpp" line="312"/>
        <source>The %1 time could not be transferred to the %2.</source>
        <translation>Nie można przenieść czasu %1 do %2.</translation>
    </message>
    <message>
        <location filename="datetime.cpp" line="350"/>
        <source>Updating...</source>
        <translation>Aktualizowanie...</translation>
    </message>
    <message>
        <location filename="datetime.cpp" line="360"/>
        <source>The system clock was updated successfully.</source>
        <translation>Zegar systemowy został pomyślnie zaktualizowany.</translation>
    </message>
    <message>
        <location filename="datetime.cpp" line="362"/>
        <source>The system clock could not be updated.</source>
        <translation>Nie można zaktualizować zegara systemowego.</translation>
    </message>
    <message>
        <location filename="datetime.cpp" line="364"/>
        <source>None of the NTP servers on the list are currently enabled.</source>
        <translation>Żaden z serwerów NTP na liście nie jest obecnie dostępny.</translation>
    </message>
    <message>
        <location filename="datetime.cpp" line="595"/>
        <source>About MX Date &amp; Time</source>
        <translation>O programie MX Data i godzina</translation>
    </message>
    <message>
        <location filename="datetime.cpp" line="596"/>
        <source>Version: </source>
        <translation>Wersja:</translation>
    </message>
    <message>
        <location filename="datetime.cpp" line="597"/>
        <source>GUI program for setting the time and date in MX Linux</source>
        <translation>Program GUI do ustawiania czasu i daty w MX Linux</translation>
    </message>
    <message>
        <location filename="datetime.cpp" line="599"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Prawa autorskie © MX Linux</translation>
    </message>
    <message>
        <location filename="datetime.cpp" line="600"/>
        <location filename="datetime.cpp" line="614"/>
        <source>License</source>
        <translation>Licencja</translation>
    </message>
    <message>
        <location filename="datetime.cpp" line="601"/>
        <source>Changelog</source>
        <translation>Dziennik zmian</translation>
    </message>
    <message>
        <location filename="datetime.cpp" line="602"/>
        <source>Cancel</source>
        <translation>Anuluj</translation>
    </message>
    <message>
        <location filename="datetime.cpp" line="628"/>
        <source>&amp;Close</source>
        <translation>&amp;Zamknij</translation>
    </message>
    <message>
        <location filename="datetime.cpp" line="646"/>
        <source>MX Date &amp; Time Help</source>
        <translation>Pomoc MX Data i godzina</translation>
    </message>
</context>
</TS>
